@@ -4,6 +4,21 @@
  *
  * Copyright (C) 2002 - 2004 the Free Software Foundation
  *
+ * GHex is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * GHex is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GHex; see the file COPYING.
+ * If not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * Author: Jaka Mocnik  <jaka@gnu.org>
  */
 
@@ -30,7 +45,7 @@
 #define GHEX_WINDOW_DEFAULT_WIDTH 320
 #define GHEX_WINDOW_DEFAULT_HEIGHT 256
 
-G_DEFINE_TYPE (GHexWindow, ghex_window, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE (GHexWindow, ghex_window, GTK_TYPE_APPLICATION_WINDOW)
 
 static GList *window_list = NULL;
 static GHexWindow *active_window = NULL;
@@ -81,7 +96,7 @@ ghex_window_drag_data_received(GtkWidget *widget,
         }
 
         if (newwin == NULL)
-            newwin = ghex_window_new ();
+            newwin = ghex_window_new (GTK_APPLICATION (g_application_get_default ()));
         if (ghex_window_load (GHEX_WINDOW (newwin), filename)) {
             if (newwin != GTK_WIDGET (win))
                 gtk_widget_show (newwin);
@@ -304,10 +319,8 @@ ghex_window_destroy (GtkWidget *object)
 
         window_list = g_list_remove(window_list, win);
 
-        if(window_list == NULL) {
-            gtk_main_quit ();
+        if (window_list == NULL)
             active_window = NULL;
-        }
         else if(active_window == win)
             active_window = GHEX_WINDOW(window_list->data);
 
@@ -637,7 +650,7 @@ ghex_window_sync_char_table_item(GHexWindow *win, gboolean state)
 }
 
 GtkWidget *
-ghex_window_new(void)
+ghex_window_new (GtkApplication *application)
 {
     GHexWindow *win;
     const GList *doc_list;
@@ -647,6 +660,7 @@ ghex_window_new(void)
 	};
 
 	win = GHEX_WINDOW(g_object_new(GHEX_TYPE_WINDOW,
+                                   "application", application,
                                    "title", _("GHex"),
                                    NULL));
 
@@ -691,9 +705,10 @@ create_document_view(HexDocument *doc)
 }
 
 GtkWidget *
-ghex_window_new_from_doc(HexDocument *doc)
+ghex_window_new_from_doc (GtkApplication *application,
+                          HexDocument    *doc)
 {
-    GtkWidget *win = ghex_window_new();
+    GtkWidget *win = ghex_window_new (application);
     GtkWidget *gh = create_document_view(doc);
 
     gtk_widget_show(gh);
@@ -709,9 +724,10 @@ ghex_window_new_from_doc(HexDocument *doc)
 }
 
 GtkWidget *
-ghex_window_new_from_file(const gchar *filename)
+ghex_window_new_from_file (GtkApplication *application,
+                           const gchar    *filename)
 {
-    GtkWidget *win = ghex_window_new();
+    GtkWidget *win = ghex_window_new (application);
 
     if(!ghex_window_load(GHEX_WINDOW(win), filename)) {
         gtk_widget_destroy(win);
@@ -1104,8 +1120,6 @@ remove_timeout_cb (GtkWidget *win, MessageInfo *mi )
 static gint
 remove_message_timeout (MessageInfo * mi)
 {
-	GDK_THREADS_ENTER ();
-
 	/* Remove the status message */
 	/* NOTE : Use space ' ' not an empty string '' */
 	ghex_window_update_status_message (mi->win);
@@ -1113,8 +1127,6 @@ remove_message_timeout (MessageInfo * mi)
                                          remove_timeout_cb, mi);
 	g_free (mi);
 
-	GDK_THREADS_LEAVE ();
-
 	return FALSE; /* removes the timeout */
 }
 
